@@ -1,16 +1,179 @@
+##' Diurnal, day of the week and monthly variation
+##'
+##' Plots the diurnal and day of the week variation for different variables,
+##' typically pollutant concentrations. Three separate plots are produced.
+##'
+##' The variation of pollutant concentrations by hour of the day and day of the
+##' week can reveal many interesting features that relate to source types. For
+##' traffic sources, there are often important differences in the way vehicles
+##' vary by vehicles type e.g. less heavy vehicles at weekends.
+##'
+##' The \code{timeVariation} function makes it easy to see how concentrations
+##' (and many other variable types) vary by hour of the day and day of the
+##' week.
+##'
+##' The plots also show the 95% confidence intervals in the mean, which is
+##' particularly useful for comparing two different pollutants whose
+##' concentrations have been normalised.
+##'
+##' Note also that the \code{timeVariation} function works well on a subset of
+##' data and in conjunction with other plots. For example, a
+##' \code{\link{polarPlot}} may highlight an interesting feature for a
+##' particular wind speed/direction range. By filtering for those conditions
+##' \code{timeVariation} can help determine whether the temporal variation of
+##' that feature differs from other features --- and help with source
+##' identification.
+##'
+##' In addition, \code{timeVariation} will work well with other variables if
+##' available. Examples include meteorological and traffic flow data.
+##'
+##' @param mydata A data frame of hourly (or higher temporal resolution data).
+##'   Must include a \code{date} field and at least one variable to plot.
+##' @param pollutant Name of variable to plot. Two or more pollutants can be
+##'   plotted, in which case a form like \code{pollutant = c("nox", "co")}
+##'   should be used.
+##' @param local.time Should the results be calculated in local time? The
+##'   default is \code{FALSE}. Emissions activity tends to occur at local time
+##'   e.g. rush hour is at 8 am every day. When the clocks go forward in
+##'   spring, the emissions are effectively released into the atmosphere at BST
+##'   - 1 hour during the summer. When plotting diurnal profiles, this has the
+##'   effect of "smearing-out" the concentrations. Sometimes, a better approach
+##'   is to express time as local time, which here is defined as BST (British
+##'   Summer Time). This correction tends to produce better-defined diurnal
+##'   profiles of concentration (or other variables) and allows a better
+##'   comparison to be made with emissions/activity data. If set to
+##'   \code{FALSE} then GMT is used.
+##' @param normalise Should variables be normalised? The default is
+##'   \code{FALSE}. If \code{TRUE} then the variable(s) are divided by their
+##'   mean values. This helps to compare the shape of the diurnal trends for
+##'   variables on very different scales.
+##' @param xlab x-axis label; one for each sub-plot.
+##' @param name.pol Names to be given to the pollutant(s). This is useful if
+##'   you want to give a fuller description of the variables, maybe also
+##'   including subscripts etc.
+##' @param type \code{type} determines how the data are split i.e. conditioned,
+##'   and then plotted. The default is will produce a single plot using the
+##'   entire data. Type can be one of the built-in types as detailed in
+##'   \code{cutData} e.g. "season", "year", "weekday" and so on. For example,
+##'   \code{type = "season"} will produce four plots --- one for each season.
+##'
+##' It is also possible to choose \code{type} as another variable in the data
+##'   frame. If that variable is numeric, then the data will be split into four
+##'   quantiles (if possible) and labelled accordingly. If type is an existing
+##'   character or factor variable, then those categories/levels will be used
+##'   directly. This offers great flexibility for understanding the variation
+##'   of different variables and how they depend on one another.
+##'
+##' Only one \code{type} is allowed in\code{timeVariation}.
+##' @param group This sets the grouping variable to be used. For example, if a
+##'   data frame had a column \code{site} setting \code{group = "site"} will
+##'   plot all sites together in each panel. See examples below.
+##' @param ci Should confidence intervals be shown? The default is \code{TRUE}.
+##'   Setting this to \code{FALSE} can be useful if multiple pollutants are
+##'   chosen where over-lapping confidence intervals can over complicate plots.
+##' @param cols Colours to be used for plotting. Options include "default",
+##'   "increment", "heat", "spectral", "hue" (default) and user defined (see
+##'   manual for more details).
+##' @param key By default \code{timeVariation} produces four plots on one page.
+##'   While it is useful to see these plots together, it is sometimes necessary
+##'   just to use one for a report. If \code{key} is \code{TRUE}, a key is
+##'   added to all plots allowing the extraction of a single plot \emph{with}
+##'   key. See below for an example.
+##' @param key.columns Number of columns to be used in the key. With many
+##'   pollutants a single column can make to key too wide. The user can thus
+##'   choose to use several columns by setting \code{columns} to be less than
+##'   the number of pollutants.
+##' @param auto.text Either \code{TRUE} (default) or \code{FALSE}. If
+##'   \code{TRUE} titles and axis labels will automatically try and format
+##'   pollutant names and units properly e.g.  by subscripting the `2' in NO2.
+##' @param alpha The alpha transparency used for plotting confidence intervals.
+##'   0 is fully transparent and 1 is opaque. The default is 0.4
+##' @param \dots Other graphical parameters passed onto \code{lattice:xyplot}
+##'   and \code{cutData}. For example, in the case of \code{cutData} the option
+##'   \code{hemisphere = "southern"}.
+##' @export
+##' @return As well as generating the plot itself, \code{timeVariation} also
+##'   returns an object of class ``openair''. The object includes three main
+##'   components: \code{call}, the command used to generate the plot;
+##'   \code{data}, the data used to make the four components of the plot (or
+##'   subplots); and \code{plot}, the associated subplots.  If retained, e.g.
+##'   using \code{output <- timeVariation(mydata, "nox")}, this output can be
+##'   used to recover the data, reproduce or rework the original plot or
+##'   undertake further analysis.
+##'
+##' An openair output can be manipulated using a number of generic operations,
+##'   including \code{print}, \code{plot} and \code{summary}. See
+##'   \code{\link{openair.generics}} for further details.
+##'
+##' The four components of timeVariation are: \code{day.hour}, \code{hour},
+##'   \code{day} and \code{month}. Associated data.frames can be extracted
+##'   directly using the \code{subset} option, e.g. as in \code{plot(object,
+##'   subset = "day.hour")}, \code{summary(output, subset = "hour")}, etc, for
+##'   \code{output <- timeVariation(mydata, "nox")}
+##' @author David Carslaw
+##' @seealso \code{\link{polarPlot}}, \code{\link{linearRelation}}
+##' @keywords methods
+##' @examples
+##'
+##'
+##' # basic use
+##' timeVariation(mydata, pollutant = "nox")
+##'
+##' # for a subset of conditions
+##' timeVariation(subset(mydata, ws > 3 & wd > 100 & wd < 270),
+##' pollutant = "pm10", ylab = "pm10 (ug/m3)")
+##'
+##' # multiple pollutants with concentrations normalised
+##' timeVariation(mydata, pollutant = c("nox", "co"), normalise = TRUE)
+##'
+##' # show BST/GMT variation (see ?cutData for more details)
+##' # the NOx plot shows the profiles are very similar when expressed in
+##' # local time, showing that the profile is dominated by a local source
+##' # that varies by local time and not by GMT i.e. road vehicle emissions
+##'
+##' timeVariation(mydata, pollutant = "nox", type = "gmtbst")
+##'
+##' ## In this case it is better to group the results for clarity:
+##' timeVariation(mydata, pollutant = "nox", group = "gmtbst")
+##'
+##' # By contrast, a variable such as wind speed shows a clear shift when
+##' #  expressed in local time. These two plots can help show whether the
+##' #  variation is dominated by man-made influences or natural processes
+##'
+##' \dontrun{timeVariation(mydata, pollutant = "ws", group = "gmtbst")}
+##'
+##' ## It is also possible to plot several variables and set type. For
+##' ## example, consider the NOx and NO2 split by levels of O3:
+##'
+##' \dontrun{timeVariation(mydata, pollutant = c("nox", "no2"), type = "o3", normalise = TRUE)}
+##'
+##' ## sub plots can be extracted from the openair object
+##' myplot <- timeVariation(mydata, pollutant = "no2")
+##' plot(myplot, subset = "day.hour") # top weekday and plot
+##'
+##' ## individual plots
+##' ## plot(myplot, subset="day.hour") for the weekday and hours subplot (top)
+##' ## plot(myplot, subset="hour") for the diurnal plot
+##' ## plot(myplot, subset="day") for the weekday plot
+##' ## plot(myplot, subset="month") for the monthly plot
+##'
+##' ## numerical results (mean, lower/upper uncertainties)
+##' ## results(myplot, subset = "day.hour") # the weekday and hour data set
+##' ## summary(myplot, subset = "hour") #summary of hour data set
+##' ## head(myplot, subset = "day") #head/top of day data set
+##' ## tail(myplot, subset = "month") #tail/top of month data set
+##'
+##'
 timeVariation <- function(mydata,
                           pollutant = "nox",
                           local.time = FALSE,
                           normalise = FALSE,
-                          ylab = pollutant,
                           xlab = c("hour", "hour", "month", "weekday"),
-                          ylim = NA,
                           name.pol = pollutant,
                           type = "default",
                           group = NULL,
                           ci = TRUE,
                           cols = "hue",
-                          main = "",
                           key = NULL,
                           key.columns = 1,
                           auto.text = TRUE,
@@ -24,6 +187,22 @@ timeVariation <- function(mydata,
         trellis.par.set(list(strip.background = list(col = "white")))
     }
 
+
+    ##extra.args setup
+    extra.args <- list(...)
+
+    #label controls
+    ##xlab handled in formals and code because unique
+    extra.args$ylab <- if("ylab" %in% names(extra.args))
+                           quickText(extra.args$ylab, auto.text) else 
+                               quickText(paste(pollutant, collapse=", "), auto.text)
+    extra.args$main <- if("main" %in% names(extra.args))
+                           quickText(extra.args$main, auto.text) else quickText("", auto.text)
+
+    #ylim
+    ylim.handler <- if("ylim" %in% names(extra.args))
+                        FALSE else TRUE
+
     vars <- c("date", pollutant)
 
     if (!missing(group) & length(pollutant) > 1) {
@@ -62,13 +241,12 @@ timeVariation <- function(mydata,
     mydata <- na.omit(mydata)
 
     ## title for overall and individual plots
-    overall.main <- quickText(main, auto.text)
-    main <- ""
+    overall.main <- extra.args$main
+    extra.args$main <- ""
 
     if (local.time) attr(mydata$date, "tzone") <- "Europe/London"
 
     ## ylabs for more than one pollutant
-    if (missing(ylab)) ylab <-  paste(pollutant, collapse = ", ")
 
     if (missing(name.pol)) mylab <- sapply(seq_along(pollutant), function(x)
                                            quickText(pollutant[x], auto.text))
@@ -96,7 +274,7 @@ timeVariation <- function(mydata,
         x
     }
 
-    if (normalise) ylab <- "normalised level"
+    if (normalise) extra.args$ylab <- "normalised level"
 
     ## calculate temporal components
     mydata <- within(mydata, {
@@ -141,7 +319,7 @@ timeVariation <- function(mydata,
         key <- list(rectangles = list(col = myColors[1:npol], border = NA),
                     text = list(lab = mylab),  space = "bottom", columns = key.columns)
 
-        main <- overall.main
+        extra.args$main <- overall.main
     }
 
 
@@ -165,21 +343,21 @@ timeVariation <- function(mydata,
     temp <- paste(type, collapse = "+")
     myform <- formula(paste("Mean ~ hour | ", temp, sep = ""))
 
-    if (missing(ylim)) ylim.hour <- rng(data.hour) else ylim.hour <- ylim
-
-    hour <- xyplot(myform,  data = data.hour, groups = variable,
+    #ylim hander
+    if(ylim.handler) 
+        extra.args$ylim <- rng(data.hour)
+  
+    #plot  
+    xyplot.args <- list(x = myform,  data = data.hour, groups = data.hour$variable,
                    as.table = TRUE,
-                   main = main,
-                   ylab = quickText(ylab, auto.text),
                    xlab = xlab[2],
                    xlim = c(0, 23),
-                   ylim = ylim.hour,
                    strip = strip,
                    par.strip.text = list(cex = 0.8),
                    key = key,
                    scales = list(x = list(at = c(0, 6, 12, 18, 23))),
                    par.settings = simpleTheme(col = myColors),
-                   panel =  panel.superpose,...,
+                   panel =  panel.superpose,
                    panel.groups = function(x, y, col.line, type, group.number, subscripts,...) {
                        if (group.number == 1) {
                            panel.grid(-1, 0)
@@ -191,6 +369,13 @@ timeVariation <- function(mydata,
                                         data.hour$Upper[subscripts], group.number)}
 
                    })
+
+    #reset for extra.args
+    xyplot.args<- listUpdate(xyplot.args, extra.args)
+
+    #plot
+    hour <- do.call(xyplot, xyplot.args)
+
     ## weekday ############################################################################
 
     data.weekday <- calc.wd(mydata, vars = "weekday", pollutant, type)
@@ -207,20 +392,20 @@ timeVariation <- function(mydata,
     temp <- paste(type, collapse = "+")
     myform <- formula(paste("Mean ~ weekday | ", temp, sep = ""))
 
-    if (missing(ylim)) ylim.weekday <- rng(data.weekday) else ylim.weekday <- ylim
-
-    day <- xyplot(myform,  data = data.weekday, groups = variable,
+    #ylim hander
+    if(ylim.handler) 
+        extra.args$ylim <- rng(data.weekday)
+  
+    #plot  
+    xyplot.args <- list(x = myform,  data = data.weekday, groups = data.weekday$variable,
                   as.table = TRUE,
                   par.settings = simpleTheme(col = myColors, pch = 16),
                   scales = list(x = list(at = 1:7, labels = format(ISOdate(2000, 1, 3:9), "%a"))),
-                  ylab = quickText(ylab, auto.text),
                   xlab = xlab[4],
-                  ylim = ylim.weekday,
                   strip = strip,
                   par.strip.text = list(cex = 0.8),
                   key = key,
-                  main = main,
-                  panel =  panel.superpose,...,
+                  panel =  panel.superpose,
                   panel.groups = function(x, y, col.line, type, group.number, subscripts,...) {
                       if (group.number == 1) {
                           panel.grid(-1, 0)
@@ -235,6 +420,12 @@ timeVariation <- function(mydata,
                                           border = NA, alpha = alpha)}
                   })
 
+    #reset for extra.args
+    xyplot.args<- listUpdate(xyplot.args, extra.args)
+
+    #plot
+    day <- do.call(xyplot, xyplot.args)
+
     ## month ############################################################################
 
     data.month <- calc.wd(mydata, vars = "month", pollutant, type)
@@ -246,22 +437,22 @@ timeVariation <- function(mydata,
     temp <- paste(type, collapse = "+")
     myform <- formula(paste("Mean ~ month | ", temp, sep = ""))
 
-    if (missing(ylim)) ylim.month <-  rng(data.month) else ylim.month <- ylim
-
-    month <- xyplot(myform,  data = data.month, groups = variable,
+    #ylim hander
+    if(ylim.handler) 
+        extra.args$ylim <- rng(data.month)
+  
+    #plot  
+    xyplot.args <- list(x = myform,  data = data.month, groups = data.month$variable,
                     as.table = TRUE,
-                    ylab = quickText(ylab, auto.text),
                     xlab = xlab[3],
-                    ylim = ylim.month,
                     xlim = c(0.5, 12.5),
                     key = key,
-                    main = main,
                     strip = strip,
                     par.strip.text = list(cex = 0.8),
                     par.settings = simpleTheme(col = myColors, pch = 16),
                     scales = list(x = list(at = 1:12, labels = substr(format(seq(as.Date("2000-01-01"),
                                                       as.Date("2000-12-31"), "month"), "%B"), 1, 1))),
-                    panel =  panel.superpose,...,
+                    panel =  panel.superpose,
                     panel.groups = function(x, y, col.line, type, group.number, subscripts,...) {
                         if (group.number == 1) {
                             panel.grid(-1, 0)
@@ -275,6 +466,13 @@ timeVariation <- function(mydata,
                                             fill = myColors[group.number],
                                             border = NA, alpha = alpha)}
                     })
+
+    #reset for extra.args
+    xyplot.args<- listUpdate(xyplot.args, extra.args)
+
+    #plot
+    month <- do.call(xyplot, xyplot.args)
+
     ## #######################################################################################
 
     ## day and hour ############################################################################
@@ -312,14 +510,14 @@ timeVariation <- function(mydata,
         myform <- formula(paste("Mean ~ hour | weekday *", temp, sep = ""))
     }
 
-    if (missing(ylim)) ylim.day.hour <-  rng(data.day.hour) else ylim.day.hour <- ylim
-
-    day.hour <- xyplot(myform ,  data = data.day.hour, groups = variable,
+    #ylim hander
+    if(ylim.handler) 
+        extra.args$ylim <- rng(data.day.hour)
+  
+    #plot  
+    xyplot.args <- list(x = myform,  data = data.day.hour, groups = data.day.hour$variable,
                        as.table = TRUE,
-                       main = main,
                        xlim = c(0, 23),
-                       ylim = ylim.day.hour,
-                       ylab = quickText(ylab, auto.text),
                        xlab = xlab[1],
                        layout = layout,
                        par.settings = simpleTheme(col = myColors),
@@ -328,7 +526,7 @@ timeVariation <- function(mydata,
                        strip = strip,
                        strip.left = strip.left,
                        par.strip.text = list(cex = 0.8),
-                       panel =  panel.superpose,...,
+                       panel =  panel.superpose,
                        panel.groups = function(x, y, col.line, type, group.number,
                        subscripts,...) {
                            ## add grid lines once (otherwise they overwrite the data)
@@ -342,6 +540,13 @@ timeVariation <- function(mydata,
                                             data.day.hour$Upper[subscripts], group.number)}
                        })
 
+    #reset for extra.args
+    xyplot.args<- listUpdate(xyplot.args, extra.args)
+
+    #plot
+    day.hour <- do.call(xyplot, xyplot.args)
+
+
     subsets = c("day.hour", "hour", "day", "month")
 
     main.plot <- function(...) {
