@@ -81,6 +81,38 @@ date.pad <- function(mydata, type = "default") {
 #############################################################################################
 
 
+
+
+##' Calculate rollingMean values
+##'
+##' Calculate rollingMean values taking account of data capture thresholds
+##'
+##' This is a utility function mostly designed to calculate rolling mean
+##' statistics relevent to some pollutant limits e.g. 8 hour rolling means for
+##' ozone and 24 hour rollingMeans for PM10.
+##'
+##' @param mydata A data frame containing a \code{date} field.
+##' @param pollutant The name of a pollutant e.g. \code{pollutant = "o3"}.
+##' @param hours The averaging period to use e.g. \code{hours = 8} will
+##'   generate 8-hour rollingMean values.
+##' @param new.name The name given to the new rollingMean variable. If not
+##'   supplied it will create a name based on the name of the pollutant and the
+##'   averaging period used.
+##' @param data.thresh The data capture threshold in %. No values are
+##'   calculated if data capture over the period of interest is less than this
+##'   value. For example, with \code{hours = 8} and \code{data.thresh = 75} at
+##'   least 6 hours are required to calculate the mean, else \code{NA} is
+##'   returned.
+##' @export
+##' @author David Carslaw
+##' @keywords methods
+##' @examples
+##'
+##' ## rolling 8-hour mean for ozone
+##' mydata <- rollingMean(mydata, pollutant = "o3", hours = 8, new.name =
+##' "rollingo3", data.thresh = 75)
+##'
+##'
 rollingMean <- function(mydata, pollutant = "o3", hours = 8, new.name = "rolling",
                          data.thresh = 75){
     ## function to calculate rolling means
@@ -143,16 +175,40 @@ convert.date <- function(mydata, format = "%d/%m/%Y %H:%M") {
 ## splits data frame into date chunks. Allows users to supply simple dates and labels
 ## useful for type = "site", interventions
 
-splitByDate <- function(mydata, dates = "1/1/2003", labels = c("before", "after")) {
+
+
+##' Divide up a data frame by time
+##'
+##' Utility function to prepare input data for use in openair functions
+##'
+##' This function partitions a data frame up into different time segments. It
+##' produces a new column called controlled by \code{name} that can be used in many
+##' \code{openair} functions. Note that there must be one more label than there
+##' are dates. See examples below and in full \code{openair} documentation.
+##'
+##' @param mydata A data frame containing a \code{date} field in hourly or high
+##'   resolution format.
+##' @param dates A date or dates to split data by.
+##' @param labels Labels for each time partition.
+##' @param name The name to give the new column to identify the periods split
+##' @export
+##' @author David Carslaw
+##' @keywords methods
+##' @examples
+##'
+##' ## split data up into "before" and "after"
+##' mydata <- splitByDate(mydata, dates = "1/04/2000",
+##' labels = c("before", "after"))
+##'
+##' ## split data into 3 partitions:
+##' mydata <- splitByDate(mydata, dates = c("1/1/2000", "1/3/2003"),
+##' labels = c("before", "during", "after"))
+##'
+##'
+splitByDate <- function(mydata, dates = "1/1/2003", labels = c("before", "after"), name = "split.by") {
     ## if date in format dd/mm/yyyy hh:mm (basic check)
     if (missing(mydata)) stop("No data frame was supplied!")
 
-    if ("site" %in% names(mydata)) {
-        if (length(levels(factor(mydata$site))) > 1 & any(duplicated(mydata$date))) {
-            stop("More than one site detected - can only deal with a single site at the moment!")
-        }
-    }
-
     mydata <- checkPrep(mydata, names(mydata), "default", remove.calm = FALSE)
     ## check there are sufficent labels for number of dates
     if (length(dates) != length(labels) - 1) {
@@ -188,7 +244,7 @@ one more label than date")
     }
 
 
-    mydata$site <- cut(as.numeric(mydata$date), breaks = c(0, as.numeric(dates),
+    mydata[ , name] <- cut(as.numeric(mydata$date), breaks = c(0, as.numeric(dates),
                                                 max(mydata$date)), labels = labels,
                        ordered_result = TRUE)
     mydata
@@ -196,6 +252,65 @@ one more label than date")
 #############################################################################################
 
 ## function to make it easy to use d/m/y format for subsetting by date
+
+
+##' Subset a data frame based on date
+##'
+##' Utility function to make it easier to select periods from a data frame
+##' before sending to a function
+##'
+##' This function makes it much easier to select periods of interest from a
+##' data frame based on dates in a British format. Selecting date/times in R
+##' format can be intimidating for new users. This function can be used to
+##' select quite complex dates simply - see examples below.
+##'
+##' Dates are assumed to be inclusive, so \code{start = "1/1/1999"} means that
+##' times are selected from hour zero. Similarly, \code{end = "31/12/1999"}
+##' will include all hours of the 31st December.
+##'
+##' All options are applied in turn making it possible to select quite complex
+##' dates
+##'
+##' @param mydata A data frame containing a \code{date} field in hourly or high
+##'   resolution format.
+##' @param start A start date in the form d/m/yyyy e.g. "1/2/1999".
+##' @param end An end date in the form d/m/yyyy e.g. "31/5/1999".
+##' @param year A year or years to select e.g. \code{year = 1998:2004} to
+##'   select 1998-2004 inclusive or \code{year = c(1998, 2004)} to select 1998
+##'   and 2004.
+##' @param month A month or months to select. Can either be numeric e.g.
+##'   \code{month = 1:6} to select months 1-6 (January to June), or by name
+##'   e.g. \code{month = c("January", "December")}. Names can be abbreviated to
+##'   3 letters and be in lower or upper case.
+##' @param day A day or or days to select. For example \code{day = c("Monday",
+##'   "Wednesday")}. Names can be abbreviated to 3 letters and be in lower or
+##'   upper case. Also accepts "weekday" (Monday - Friday) and "weekend" for
+##'   convenience.
+##' @param hour An hour or hours to select from 0-23 e.g. \code{hour = 0:12} to
+##'   select hours 0 to 12 inclusive.
+##' @param use.local.tz Used when \code{start} and \code{end} dates are
+##'   supplied. The default is to use any time zone information supplied and if
+##'   not, assume GMT/UTC.
+##' @export
+##' @author David Carslaw
+##' @keywords methods
+##' @examples
+##'
+##' ## select all of 1999
+##' data.1999 <- selectByDate(mydata, start = "1/1/1999", end = "31/12/1999")
+##' head(data.1999)
+##' tail(data.1999)
+##'
+##' # easier way
+##' data.1999 <- selectByDate(mydata, year = 1999)
+##'
+##' # more complex use: select weekdays between the hours of 7 am to 7 pm
+##' sub.data <- selectByDate(mydata, day = "weekday", hour = 7:19)
+##'
+##' # select weekends between the hours of 7 am to 7 pm in winter (Dec, Jan, Feb)
+##' sub.data <- selectByDate(mydata, day = "weekend", hour = 7:19, month =
+##' c("dec", "jan", "feb"))
+##'
 selectByDate <- function (mydata, start = "1/1/2008", end = "31/12/2008", year = 2008,
     month = 1, day = "weekday", hour = 1, use.local.tz = TRUE)
 
